\name{nmfeu}
\alias{nmfeu}
\title{Non-negative Matrix Factorization: Euclidean Distance}
\description{

  \code{nmfeu}: \R implementation of  \code{nmfeu}.
}
\usage{

nmfeu(X,p,cyc=100)


}
\arguments{
  \item{X}{the data matrix.}
  \item{p}{number of hidden factor.}
  \item{cyc}{maximal number of iterations.}
}
\details{

   Non-negative Matrix Factorization represents positive matrix
  \eqn{X} by positive matrices \eqn{L} and \eqn{Z}.

   Objective for reconstruction is Euclidean distance.

  \deqn{X \ = \ L \ Z }

  \deqn{X \ = \ \sum_{i=1}^{p} L_i \
                   \left(Z_i \right)^T}




	 The model selection is performed
	 according  to  D. D. Lee and H. S. Seung, 2001.


  The code is implemented in \R.

}
\value{
  \item{L}{Left matrix:  \eqn{L}}
  \item{Z}{Right matrix:  \eqn{Z}}
    }
\seealso{
\code{\link{fabi}},
\code{\link{fabia}},
\code{\link{fabiap}},
\code{\link{fabias}},
\code{\link{fabiasp}},
\code{\link{mfsc}},
\code{\link{nmfdiv}},
\code{\link{nmfsc}},
\code{\link{nprojfunc}},
\code{\link{projfunc}},
\code{\link{make_fabi_data}},
\code{\link{make_fabi_data_blocks}},
\code{\link{make_fabi_data_pos}},
\code{\link{make_fabi_data_blocks_pos}},
\code{\link{extract_plot}},
\code{\link{extract_bic}},
\code{\link{myImagePlot}},
\code{\link{PlotBicluster}},
\code{\link{Breast_A}},
\code{\link{DLBCL_B}},
\code{\link{Multi_A}},
\code{\link{fabiaDemo}},
\code{\link{fabiaVersion}}
}
\author{Sepp Hochreiter}
\examples{


#---------------
# TEST
#---------------

dat <- make_fabi_data_blocks(n = 100,l= 50,p = 3,f1 = 5,f2 = 5,
  of1 = 5,of2 = 10,sd_noise = 3.0,sd_z_noise = 0.2,mean_z = 2.0,
  sd_z = 1.0,sd_l_noise = 0.2,mean_l = 3.0,sd_l = 1.0)

X <- dat[[1]]
Y <- dat[[2]]
X <- abs(X)
XX <- tcrossprod(X)
dXX <- 1/sqrt(diag(XX))
X <- dXX*X


resEx <- nmfeu(as.matrix(abs(X)),3)


\dontrun{
#---------------
# DEMO
#---------------

dat <- make_fabi_data_blocks(n = 1000,l= 100,p = 10,f1 = 5,f2 = 5,
  of1 = 5,of2 = 10,sd_noise = 3.0,sd_z_noise = 0.2,mean_z = 2.0,
  sd_z = 1.0,sd_l_noise = 0.2,mean_l = 3.0,sd_l = 1.0)

X <- dat[[1]]
Y <- dat[[2]]
X <- abs(X)
XX <- tcrossprod(X)
dXX <- 1/sqrt(diag(XX))
X <- dXX*X


resToy <- nmfeu(as.matrix(abs(X)),8)

rToy <- extract_plot(X,resToy$L,resToy$Z,ti="NMFEU",Y=Y)

}
}
\references{

  Paatero, P and Tapper, U,
  \sQuote{Least squares formulation of robust non-negative factor analysis},
  Chemometr. Intell. Lab. 37: 23-35, 1997.

  D. D. Lee and H. S. Seung,
  \sQuote{Algorithms for non-negative matrix factorization},
  In Advances in Neural Information Processing Systems 13, 556-562,
  2001.

}
\keyword{methods}
\concept{sparse coding}
\concept{non-negative matrix factorization}
